@@ -1,7 +1,6 @@
 package skyview.executive;
 
 // External classes used in this class.
-
 import skyview.survey.Survey;
 import skyview.survey.SurveyFinder;
 import skyview.survey.UserSurvey;
@@ -257,11 +256,15 @@ public class Imager {
      *  for usage.
      */
     public static void main(String[] args) throws Exception {
-               
+
+	if (args.length > 0 && args[0].equalsIgnoreCase("version")) {
+	    System.out.println("SkyView version is "+getVersion());
+	    return;
+	}
         // Check system level setup (currently HTTP proxy).        
         systemInit();
-        
 	if (args.length == 0) {
+	    System.out.println("SkyView version is "+getVersion());
 	    usage();
 	} else {
 	    Imager  im = getImager();
@@ -572,7 +575,6 @@ public class Imager {
     }
     
     public Survey loadSurvey(String surveyID) throws Exception {
-	
 	Survey surv;
 	//Survey surv = finder.find(surveyID);
 	if (surveyID.toLowerCase().equals("user")) {
@@ -686,7 +688,13 @@ public class Imager {
 	if (maxSize <= 0) {
 	    throw new Exception("Ouput region has nil size");
 	}
-	Image[]  cand  = surv.getImages(pos, maxSize, wcs.getScale()*180/Math.PI);
+	Image[] cand;  
+	try {
+	    cand  = surv.getImages(pos, maxSize, wcs.getScale()*180/Math.PI);
+	} catch (Throwable e) {
+	    //System.err.println(e);
+	    throw new Exception("Exception from getImages:  "+e.getMessage(), e);
+	}
         //--- If no candidates there is no reason to continue
         if (cand.length == 0  && !Settings.has("nullimages")) {
 	    String msg = "Survey: "+Settings.get("_currentSurvey")+" No candidate images were found in the region.  Position may be outside the coverage area.";
@@ -799,23 +807,37 @@ public class Imager {
 	}
     }
     
+    String planckParser( String surveyID ) throws Exception {
+	//  "planck 030 I" or "planck030i" or "planck030 i" or "planck-030 i" 
+	// Old way
+	//String[] elements = surveyID.split(" ");
+
+	Pattern p = Pattern.compile("(i|pi|pa|q|u)$");  
+	String[] elements = p.split(surveyID);  
+	String base=elements[0];  
+	// The base is anything up-to and including the numbers.  
+
+	return base;  
+    } 
+
     Image[] processComponents(String surveyID, String[] components) throws Exception {
         
         // Pop out the settings for the current (compound) survey
         // so that they don't interfere with the settings of the
         // components.
         HashMap<String,String> originalSettings = Settings.pop();
-        
-        String[] elements = surveyID.split(" ");
-        String base = "";
-        for (int i = 0; i < elements.length - 1; i += 1) {
-            base += elements[i] + " ";
-        }
+
+	String base="";
+        if (surveyID.toLowerCase().startsWith("planck")) {
+		base=planckParser(surveyID);
+	} else {
+	    System.err.println("ERROR:  You need to add a surveyID parser for any multi-component surveys that are not Planck.");
+	    return null;
+	}
         Image[] comps = new Image[components.length];
         Image oldOutput = output;
         Survey oldSurv = surv;
         for (int i = 0; i < components.length; i += 1) {
-            
             // Save this set of settings so we can get back to this
             // for each component.
             Settings.save();
@@ -867,7 +889,7 @@ public class Imager {
 	return sum;
     }
     
-    public Image doProcessSurvey(String surveyID, Survey surv) throws Exception {
+   public Image doProcessSurvey(String surveyID, Survey surv) throws Exception {
 	
 	processes = new ArrayList<Processor>();
 	if (surv == null) {
