@@ -25,7 +25,7 @@ public class AkariGenerator extends SIAPGenerator {
      * @param spells 
      */
     
-    public void getImages(double ra, double dec, double size, ArrayList<String> spells) {
+    public void getImages(double ra, double dec, double size, ArrayList<String> spells) throws Exception {
         CoordinateSystem ecl = CoordinateSystem.factory("E2000");
         double[] junit = skyview.geometry.Util.unit(new double[]{Math.toRadians(ra),Math.toRadians(dec)});
         double[] eunit = ecl.getRotater().transform(junit);
@@ -34,4 +34,4 @@ public class AkariGenerator extends SIAPGenerator {
         dec = Math.toDegrees(ecoords[1]);
         super.getImages(ra, dec, size, spells);               
     }
-}
\ No newline at end of file
+}
