@@ -40,7 +40,7 @@ public class SIAPGenerator implements ImageGenerator {
     
     
     /** Get images from a SIAP service */
-    public void getImages(double ra, double dec, double size, java.util.ArrayList<String> spells)  {
+    public void getImages(double ra, double dec, double size, java.util.ArrayList<String> spells) throws Exception  {
         
 	
 	String urlString = getBaseURL();
